package com.tutorialesprogramacionya.compose32

import android.os.Bundle
import android.view.MotionEvent
import android.view.WindowManager
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Canvas
import androidx.compose.foundation.horizontalScroll
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.rememberScrollState
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.ExperimentalComposeUiApi
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.pointer.pointerInteropFilter
import androidx.compose.ui.unit.dp

class MainActivity : ComponentActivity() {
    @ExperimentalComposeUiApi
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContent {
            PantallaPrincipal()
        }
    }
}

data class Punto(val x: Float, val y: Float, val color: Color)

@ExperimentalComposeUiApi
@Composable
fun PantallaPrincipal() {
    val puntos = remember { mutableStateListOf<Punto>() }
    var colorSeleccionado by remember { mutableStateOf(Color.Red) }
    Column(
    ) {
        SelectorColor(seleccion = {
            colorSeleccionado = it
        })
        Canvas(modifier = Modifier
            .fillMaxSize()
            .pointerInteropFilter {
                when (it.actionMasked) {
                    MotionEvent.ACTION_UP -> {
                        puntos.add(Punto(-1f, -1f, colorSeleccionado))
                        true
                    }
                    MotionEvent.ACTION_MOVE -> {

                        puntos.add(Punto(it.x, it.y, colorSeleccionado))
                        true
                    }
                    MotionEvent.ACTION_DOWN -> {
                        puntos.add(Punto(it.x, it.y, colorSeleccionado))
                        true
                    }
                    else -> false
                }
            }) {
            var primera = true
            var iniciox = 0f
            var inicioy = 0f
            for (punto in puntos) {
                if (punto.x == -1f && punto.y == -1f) {
                    primera = true
                } else
                    if (primera) {
                        iniciox = punto.x
                        inicioy = punto.y
                        primera = false
                    } else {
                        drawLine(
                            color = punto.color,
                            start = Offset(x = iniciox, y = inicioy),
                            end = Offset(x = punto.x, y = punto.y),
                            strokeWidth = 12f
                        )
                        iniciox = punto.x
                        inicioy = punto.y
                    }
            }
        }
    }
}

@Composable
fun SelectorColor(seleccion: (color: Color) -> Unit) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .horizontalScroll(rememberScrollState()),
        horizontalArrangement = Arrangement.SpaceBetween
    ) {
        for (rojo in 0..255 step 30)
            for (verde in 0..255 step 30)
                for (azul in 0..255 step 30)
                    Button(
                        modifier=Modifier.height(60.dp),
                        onClick = { seleccion(Color(rojo,verde,azul)) },
                        colors = ButtonDefaults.textButtonColors(
                            backgroundColor = Color(rojo,verde,azul)
                        )
                    ) {
                    }
    }
}